<?php
/**
 * coup Theme Customizer.
 *
 * @package coup
 */

// Load Customizer specific functions
require get_template_directory() . '/inc/customizer/functions/customizer-sanitization.php';
require get_template_directory() . '/inc/customizer/functions/customizer-functions.php';

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function coup_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	// Remove default Colors section
	$wp_customize->remove_section( 'colors' );

	// Remove default Header options except Display header text option
	$wp_customize->remove_control( 'header_image' );
	$wp_customize->remove_control( 'header_textcolor' );

	/**
	 * Upsells
	 */
	require_once( trailingslashit( get_template_directory() ) . 'inc/class/class-customizer-theme-info-control/class-customizer-theme-info-control.php' );

	$wp_customize->add_section( 'coup_theme_info_main_section', array(
	    'title'    => __( 'See the full Coup features', 'coup' ),
	    'priority' => 1,
	) );
	$wp_customize->add_setting( 'coup_theme_info_main_control', array(
	    'sanitize_callback' => 'esc_html',
	) );
	$wp_customize->add_setting( 'coup_theme_info_main_control_2', array(
	    'sanitize_callback' => 'esc_html',
	) );

	/*
	 * View Pro Version Section Control
	 */
	$wp_customize->add_control( new coup_Control_Upsell_Theme_Info( $wp_customize, 'coup_theme_info_main_control', array(
	    'section'     => 'coup_theme_info_main_section',
	    'priority'    => 100,
	    'options'     => array(
	        esc_html__( 'Shuffle Layout', 'coup' ),
	        esc_html__( 'Change Colors', 'coup' ),
	        esc_html__( 'Change Fonts', 'coup' ),
	        esc_html__( 'Built-in Portfolio', 'coup' ),
	        esc_html__( 'Support', 'coup' ),
	        esc_html__( 'Change Credit Footer Link', 'coup' ),
	        esc_html__( 'Fullwidth Slider', 'coup' ),
	    ),
	    'button_url'  => esc_url( 'https://themeskingdom.com/wordpress-themes/coup-architects-blog-portfolio-theme/' ),
	    'button_text' => esc_html__( 'See Coup', 'coup' ),
	) ) );

	$wp_customize->add_control( new coup_Control_Upsell_Theme_Info( $wp_customize, 'coup_theme_info_main_control_2', array(
	    'section'     => 'coup_theme_info_main_section',
	    'priority'    => 101,
	    'options'     => array(
	        esc_html__( 'Shuffle Layout', 'coup' ),
	        esc_html__( 'Change Colors', 'coup' ),
	        esc_html__( 'Change Fonts', 'coup' ),
	        esc_html__( 'Built-in Portfolio', 'coup' ),
	        esc_html__( 'Support', 'coup' ),
	        esc_html__( 'Change Credit Footer Link', 'coup' ),
	        esc_html__( 'Fullwidth Slider', 'coup' ),
	        esc_html__( 'Customizable Slider', 'coup' ),
	        esc_html__( 'Built-in Shop', 'coup' ),
	        esc_html__( 'Multiple Shop Layouts', 'coup' ),
	        esc_html__( 'Cart', 'coup' ),
	    ),
	    'button_url'  => esc_url( 'https://themeskingdom.com/wordpress-themes/coupshop-woocommerce-wordpress-theme/' ),
	    'button_text' => esc_html__( 'See Coup Shop', 'coup' ),
	) ) );

}
add_action( 'customize_register', 'coup_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function coup_customize_preview_js() {
	wp_enqueue_script( 'coup-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'coup_customize_preview_js' );
